# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2022-12-15 10:52:33
:LastEditTime: 2022-12-15 13:59:26
:LastEditors: HuangJingCan
:Description: 
"""
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class FunctionSkinModel(CacheModel):

    def __init__(self, db_connect_key='db_middler_platform', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(FunctionSkinModel, self).__init__(FunctionSkin, sub_table)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类


class FunctionSkin:
    def __init__(self):
        super(FunctionSkin, self).__init__()
        self.id = 0  # id
        self.product_id = 0  # 产品id
        self.theme_name = ""  # 名称
        self.theme_id = 0  # 主题id
        self.use_count = 0  # 使用数量
        self.sort_index = 0  # 排序
        self.is_release = 0  # 是否发布：0未发布1已发布
        self.operation_user = ""  # 操作用户
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'product_id', 'theme_name', 'theme_id', 'use_count', 'sort_index', 'is_release', 'operation_user', 'create_date', 'modify_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "function_skin_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-07-22 16:03:01
@LastEditTime: 2024-01-03 10:46:25
@LastEditors: HuangJianYi
@Description: 
"""
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class UserBlackModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(UserBlackModel, self).__init__(UserBlack, sub_table)
        db_connect_key, self.redis_config_dict = SevenHelper.get_connect_config("db_user","redis_user", db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class UserBlack:

    def __init__(self):
        super(UserBlack, self).__init__()
        self.id = 0  # 标识
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.user_id = 0  # 用户标识
        self.open_id = ""  # open_id
        self.user_nick = ""  # 用户昵称
        self.black_type = 0  # 拉黑类型（1自动2手动）
        self.reason = ""  # 申请原因
        self.audit_status = 0  # 审核状态(0黑名单1申请中2同意3拒绝)
        self.audit_remark = ""  # 审核备注
        self.refund_count = 0  # 退款次数
        self.refund_order_data = ""  # 退款主订单号(逗号分隔)
        self.create_date = "1900-01-01 00:00:00"  # 申请时间
        self.audit_date = "1900-01-01 00:00:00"  # 审核时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'user_id', 'open_id', 'user_nick', 'black_type', 'reason', 'audit_status', 'audit_remark', 'refund_count', 'refund_order_data', 'create_date', 'audit_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "user_black_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-07-27 10:55:09
@LastEditTime: 2021-07-29 18:34:42
@LastEditors: HuangJianYi
@Description: 
"""
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class ProductPriceModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(ProductPriceModel, self).__init__(ProductPrice, sub_table)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class ProductPrice:

    def __init__(self):
        super(ProductPrice, self).__init__()
        self.id = 0  # id
        self.plan_name = ""  # 计划名称
        self.begin_time = "1900-01-01 00:00:00"  # 开始时间
        self.end_time = "1900-01-01 00:00:00"  # 结束时间
        self.content = ""  # 内容 举例:[{'price': 1, 'link_url': '2', 'time': '3个月', 'costprice': 1, 'title': '1'}, {'price': 2, 'link_url': '3', 'time': '6个月', 'costprice': 2, 'title': '2'}, {'price': 4, 'link_url': '5', 'time': '12个月', 'costprice': 4, 'title': '4'}]
        self.project_code = "" # 项目编码
        self.is_release = 0  # 是否发布（1是0否）
        self.release_date = "1900-01-01 00:00:00"  # 发布时间
        self.create_time = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 更新时间

    @classmethod
    def get_field_list(self):
        return ['id', 'plan_name', 'begin_time', 'end_time', 'content', 'project_code', 'is_release', 'release_date', 'create_time', 'modify_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "product_price_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-11-24 09:36:39
@LastEditTime: 2025-03-10 15:54:03
@LastEditors: HuangJianYi
@Description: ERP控制台业务模型(用于跟遁甲系统对接，推送订单和回写物流) 需在配置文件加 armor_url 和 armor_sign_key对应的值
"""

import threading, multiprocessing
from seven_framework import *
from seven_cloudapp_frame.libs.common.frame_console import *
from seven_cloudapp_frame.libs.common import *
from seven_cloudapp_frame.libs.customize.seven_helper import *
from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
from seven_cloudapp_frame.models.db_models.erp.erp_relation_model import *
from seven_cloudapp_frame.models.db_models.prize.prize_order_model import *
from seven_cloudapp_frame.models.db_models.prize.prize_roster_model import *
from seven_cloudapp_frame.models.db_models.act.act_info_model import *


class ErpConsoleModel():
    """
    :description: ERP控制台业务模型(用于跟遁甲系统对接，推送订单和回写物流)
    """
    def __init__(self):
        """
        :description: 初始化
        :return: 
        :last_editors: HuangJianYi
        """
        self.db_connect_key, self.redis_config_dict = SevenHelper.get_connect_config("db_order","redis_order")

    def console_erp(self, mod_count=1, prize_roster_model=None, process_type=1):
        """
        :description: 控制台推送订单和回写物流
        :param mod_count: 单表队列数
        :param prize_roster_model: 中奖记录model实例化
        :param process_type: 处理方式（1.redis 2.api） 如果是淘系使用redis处理方式非淘系用api模式
        :return: 
        :last_editors: HuangJianYi
        """
        for i in range(mod_count):

            t = threading.Thread(target=self.process_order_push, args=[i, mod_count, True, prize_roster_model])
            t.start()

            j = threading.Thread(target=self.process_order_pull, args=[i, mod_count, process_type, prize_roster_model])
            j.start()

    def process_order_push(self, mod_value, mod_count, is_loop=True, prize_roster_model=None, decrypt_field_list=["real_name","telephone","province","city","county","street","address"]):
        """
        :description: 处理订单推送到遁甲系统
        :param mod_value: 当前队列值
        :param mod_count: 队列数
        :param is_loop: 是否循环
        :param prize_roster_model: 中奖记录model实例化
        :param decrypt_field_list: 需要解密的字段列表
        :return: 
        :last_editors: HuangJianYi
        """
        page_size = 100
        push_url = share_config.get_value("armor_url", "") + "/api/new_order"
        sign_key = share_config.get_value("armor_sign_key", "")

        print(f"{TimeHelper.get_now_format_time()} 推送订单队列{mod_value}启动")

        while True:
            try:
                time.sleep(1)
                heart_beat_monitor("process_order_push")
                erp_relation_model = ErpRelationModel()
                frame_base_model = FrameBaseModel()
                now_date = TimeHelper.get_now_format_time()
                if mod_count == 1:
                    erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>sync_date and start_date<=%s and end_date>=%s", order_by="sync_date asc", limit="200", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
                else:
                    erp_relation_list = erp_relation_model.get_dict_list("MOD(id,%s)=%s and is_release=1 and %s>sync_date and start_date<=%s and end_date>=%s", order_by="sync_date asc", limit="200", params=[mod_count, mod_value, TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
                if len(erp_relation_list) > 0:
                    for erp_relation_dict in erp_relation_list:
                        try:
                            erp_relation_model.update_table("sync_date=%s", "id=%s", params=[TimeHelper.get_now_format_time(), erp_relation_dict["id"]])
                            prize_order_model = PrizeOrderModel().set_sub_table(erp_relation_dict["app_id"])
                            if not prize_roster_model:
                                prize_roster_model = PrizeRosterModel().set_sub_table(erp_relation_dict["app_id"])
                            condition = "app_id=%s and order_status=0 and sync_status=0 and create_date<%s"
                            params = [erp_relation_dict["app_id"], TimeHelper.add_minutes_by_format_time(minute=-5)]
                            record_count = prize_order_model.get_total(condition, params=params)
                            page_count = SevenHelper.get_page_count(page_size, record_count)
                            for page_index in range(page_count):
                                prize_order_dict_list = prize_order_model.get_dict_list(condition, "", order_by="id asc", limit=str(page_size), field="*", params=params)
                                for prize_order_dict in prize_order_dict_list:
                                    prize_order_dict, status = frame_base_model.sensitive_decrypt(prize_order_dict, decrypt_field_list)
                                    if status == 0:
                                        prize_order_model.update_table("sync_status=2,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), f"敏感字段解密失败,ex:{traceback.format_exc()}", prize_order_dict["id"]])
                                        continue
                                    request_params = self.compose_push_request_params(sign_key, erp_relation_dict, prize_order_dict, prize_roster_model)
                                    if request_params["goods"]:
                                        result = HTTPHelper.post(push_url, request_params, {"Content-Type": "application/json"})
                                        if result and result.ok:
                                            prize_order_model.update_table("sync_status=1,sync_date=%s", "id=%s", params=[TimeHelper.get_now_format_time(), prize_order_dict["id"]])
                                        else:
                                            prize_order_dict["sync_count"] = prize_order_dict["sync_count"] + 1
                                            if prize_order_dict["sync_count"] == 10:
                                                prize_order_model.update_table("sync_status=2,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), SevenHelper.json_dumps(result), prize_order_dict["id"]])
                                            else:
                                                prize_order_model.update_table("sync_count=sync_count+1,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), SevenHelper.json_dumps(result), prize_order_dict["id"]])
                                    else:
                                        prize_order_model.update_table("sync_status=2,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), "推送订单失败，没有商品信息", prize_order_dict["id"]])

                        except Exception as ex:
                            logger_error.error(f"推送订单队列{mod_value}异常,json串:{SevenHelper.json_dumps(erp_relation_dict)},ex:{traceback.format_exc()}")
                            continue

                if is_loop == True and len(erp_relation_list) <= 0:
                    time.sleep(60)
                if is_loop == False:
                    break
            except Exception as ex:
                time.sleep(5)

    def compose_push_request_params(self, sign_key, erp_relation_dict, prize_order_dict, prize_roster_model):
        """
        :description: 合成请求参数
        :param sign_key: 接口签名key
        :param erp_relation_dict: erp关联信息
        :param prize_order_dict: 订单信息
        :param prize_roster_model: 中奖记录实例
        :return: 
        :last_editors: HuangJianYi
        """
        data = {}
        data["product_id"] = config.get_value("project_name", 0)
        data["business_name"] = erp_relation_dict["store_name"]
        data["app_id"] = erp_relation_dict["app_id"]
        data["app_key"] = erp_relation_dict["app_key"]
        data["mini_order"] = prize_order_dict["order_no"]
        data["user_id"] = prize_order_dict["user_id"]
        data["open_id"] = prize_order_dict["open_id"]
        data["user_account"] = prize_order_dict["user_nick"]
        data["order_time"] = TimeHelper.datetime_to_timestamp(prize_order_dict["create_date"]) * 1000 if str(prize_order_dict["create_date"]) != "1900-01-01 00:00:00" else 0
        data["activity_id"] = prize_order_dict["act_id"]
        data["activity_name"] = ""
        data["order_price"] = str(prize_order_dict['order_price'])
        data["consignee"] = prize_order_dict["real_name"]
        data["phone"] = prize_order_dict["telephone"]
        data["province"] = prize_order_dict["province"]
        data["city"] = prize_order_dict["city"]
        data["county"] = prize_order_dict["county"]
        data["street"] = prize_order_dict["street"]
        data["address"] = prize_order_dict["address"]
        data["remark"] = prize_order_dict["seller_remark"]
        data["buyer_remark"] = prize_order_dict["buyer_remark"]
        data["freight_price"] = str(prize_order_dict["freight_price"])
        data["timestamp"] = TimeHelper.get_now_timestamp(True)
        data["order_status"] = prize_order_dict["order_status"]
        if data["order_status"] == 2:
            data["order_status"] = -1  #遁甲系统 不予发货固定是-1
        if data["order_status"] == 1:
            data["logistics_number"] = prize_order_dict["express_no"]
            data["logistics_company"] = prize_order_dict["express_company"]
            data["delivery_time"] = TimeHelper.datetime_to_timestamp(prize_order_dict["deliver_date"]) * 1000 if str(prize_order_dict["deliver_date"]) != "1900-01-01 00:00:00" else 0

        goods_list = []
        prize_roster_list_dict = prize_roster_model.get_dict_list("order_no=%s", "", "id desc", "", "*", prize_order_dict["order_no"])
        for prize_roster_dict in prize_roster_list_dict:
            goods = {}
            goods["main_order"] = prize_roster_dict["main_pay_order_no"]
            goods["sub_order"] = prize_roster_dict["sub_pay_order_no"]
            goods["goods_name"] = prize_roster_dict["prize_name"]
            goods["goods_price"] = str(prize_roster_dict["prize_price"])
            goods["goods_code"] = prize_roster_dict["goods_code"]
            goods["goods_id"] = prize_roster_dict["goods_id"]
            goods["sku"] = prize_roster_dict["sku_id"]
            goods["goods_count"] = 1
            goods_list.append(goods)
        data["goods"] = goods_list
        data["sign"] = SignHelper.params_sign_md5(data, sign_key)
        return data

    def process_order_pull(self, mod_value, mod_count, process_type=1, prize_roster_model=None):
        """
        :description: 处理订单拉取，同步物流信息
        :param mod_value: 当前队列值
        :param mod_count: 队列数
        :param process_type: 处理方式（1.redis 2.api） 如果是淘系使用redis处理方式非淘系用api模式
        :param prize_roster_model: 中奖记录model实例化
        :return: 
        :last_editors: HuangJianYi
        """
        print(f"{TimeHelper.get_now_format_time()} 拉取订单队列{mod_value}启动")
        #获取产品id
        project_name = config.get_value("project_name", 0)
        while True:
            try:
                time.sleep(1)
                heart_beat_monitor("process_order_pull")
                erp_relation_model = ErpRelationModel()
                erp_redis_init = SevenHelper.redis_init(config_dict=config.get_value("erp_redis"))
                # frame_base_model = FrameBaseModel()
                now_date = TimeHelper.get_now_format_time()
                if mod_count == 1:
                    erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>return_date and start_date<=%s and end_date>=%s", order_by="return_date asc", limit="200", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
                else:
                    erp_relation_list = erp_relation_model.get_dict_list("MOD(id,%s)=%s and is_release=1 and %s>return_date and start_date<=%s and end_date>=%s", order_by="return_date asc", limit="200", params=[mod_count, mod_value, TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
                if len(erp_relation_list) > 0:
                    for erp_relation_dict in erp_relation_list:
                        try:
                            prize_order_model = PrizeOrderModel().set_sub_table(erp_relation_dict["app_id"])
                            if not prize_roster_model:
                                prize_roster_model = PrizeRosterModel().set_sub_table(erp_relation_dict["app_id"])
                            erp_relation_model.update_table("return_date=%s", "id=%s", params=[TimeHelper.get_now_format_time(), erp_relation_dict["id"]])
                            if process_type == 1:
                                key = "order_" + project_name + "_" + erp_relation_dict["app_id"]
                                tatal_count = erp_redis_init.llen(key)
                                if tatal_count <= 0:
                                    #logger_info.info("redis订单数量：" + str(tatal_count) + "，key=" + key)
                                    continue
                                index = 0
                                while True:
                                    order_info_json = erp_redis_init.lindex(key, index=index)
                                    if not order_info_json:
                                        break
                                    order_info_dict = json.loads(order_info_json)
                                    order_status = order_info_dict["order_status"]
                                    order_no = order_info_dict["mini_order"]
                                    express_no = order_info_dict["logistics_number"]
                                    express_company = order_info_dict["logistics_company"]
                                    delivery_time = order_info_dict["delivery_time"]
                                    modify_date = TimeHelper.get_now_datetime()
                                    if order_status == 1:
                                        delivery_time = TimeHelper.timestamp_to_datetime(delivery_time)
                                        update_sql = "order_status=1,express_no=%s,express_company=%s,deliver_date=%s,sync_date=%s"
                                        params = [express_no, express_company, delivery_time, modify_date, order_no]
                                        prize_order_model.update_table(update_sql, "order_no=%s", params=params)
                                        prize_roster_model.update_table("logistics_status=1", "app_id=%s and order_no=%s", params=[erp_relation_dict["app_id"], order_no])
                                        self.process_order_pull_executed(order_info_dict)
                                    else:
                                        update_sql = "sync_status=2,sync_date=%s,sync_result=%s"
                                        params = [modify_date, "拉取订单失败", order_no]
                                        prize_order_model.update_table(update_sql, "order_no=%s", params=params)
                                    #删除redis缓存
                                    erp_redis_init.lpop(key)
                            else:
                                page_size = 100
                                pull_url = share_config.get_value("armor_url","") + "/api/new_get_order"
                                sign_key = share_config.get_value("armor_sign_key", "")
                                condition = "app_id=%s and order_status=0 and sync_status=1"
                                params = [erp_relation_dict["app_id"]]
                                record_count = prize_order_model.get_total(condition, params=params)
                                page_count = SevenHelper.get_page_count(page_size, record_count)
                                for page_index in range(0, page_count):
                                    prize_order_dict_list = prize_order_model.get_dict_page_list("id,order_no", page_index, page_size, condition, "", "id asc", params, page_count_mode="none")
                                    if prize_order_dict_list and len(prize_order_dict_list) > 0:
                                        order_no_list = [prize_order['order_no'] for prize_order in prize_order_dict_list]
                                        data = {}
                                        data["mini_order"] = ",".join(order_no_list)
                                        data["timestamp"] = TimeHelper.get_now_timestamp(True)
                                        data["sign"] = SignHelper.params_sign_md5(data, sign_key)
                                        result = HTTPHelper.post(pull_url, data, {"Content-Type": "application/json"})
                                        if result and result.ok:
                                            result = json.loads(result.text)
                                            data_list = result["data"]
                                            if not data_list:
                                                continue
                                            data_list = [i for i in data_list if i['order_status'] in (1, 2)]
                                            if data_list:
                                                for data in data_list:
                                                    order_status = data["order_status"]
                                                    order_no = data["mini_order"]
                                                    express_no = data["logistics_number"]
                                                    express_company = data["logistics_company"]
                                                    delivery_time = data["delivery_time"]
                                                    modify_date = TimeHelper.get_now_datetime()
                                                    if order_status == 1:
                                                        delivery_time = TimeHelper.timestamp_to_datetime(delivery_time)
                                                        update_sql = "order_status=1,express_no=%s,express_company=%s,deliver_date=%s,sync_date=%s"
                                                        update_params = [express_no, express_company, delivery_time, modify_date, order_no]
                                                        prize_order_model.update_table(update_sql, "order_no=%s", params=update_params)
                                                        prize_roster_model.update_table("logistics_status=1", "app_id=%s and order_no=%s", params=[erp_relation_dict["app_id"], order_no])
                                                        self.process_order_pull_executed(data)
                                                    else:
                                                        update_sql = "sync_status=2,sync_date=%s,sync_result=%s"
                                                        update_params = [modify_date, "拉取订单失败", order_no]
                                                        prize_order_model.update_table(update_sql, "order_no=%s", params=update_params)
                        except Exception as ex:
                            logger_error.error(f"拉取订单队列{mod_value}异常,json串:{SevenHelper.json_dumps(erp_relation_dict)},ex:{traceback.format_exc()}")
                            continue
                else:
                    time.sleep(60)
            except Exception as ex:
                time.sleep(5)

    def process_order_pull_executed(self, order_info_dict):
        """
        :description: 拉取订单执行后事件
        :param order_info_dict: 订单信息字典
        :return: 
        :last_editors: HuangJianYi
        """



# -*- coding: utf-8 -*-
"""
:Author: HuangJianYi
:Date: 2023-02-09 18:29:31
@LastEditTime: 2025-06-25 16:01:40
@LastEditors: HuangJianYi
:Description: tornado引用
"""
# 框架引用
from seven_framework.web_tornado.base_tornado import *
from seven_cloudapp_frame.libs.common import *

# 初始化配置,执行顺序需先于调用模块导入
share_config.init_config("share_config.json")  # 全局配置,只需要配置一次


# nacos配置获取
nacos_share_config = config.get_value("nacos_share", None)
if nacos_share_config:
    nacos_share_host = nacos_share_config["host"]
    nacos_share_namespace = nacos_share_config["namespace"]
    nacos_share_data_id = nacos_share_config['data_id']
    nacos_share_group = nacos_share_config.get("group", "DEFAULT_GROUP")
    nacos_share_username = nacos_share_config.get("username", None)
    nacos_share_password = nacos_share_config.get("password", None)
    config_file = "share_config.json"
    if not nacos_share_host or not nacos_share_namespace or not nacos_share_data_id or not nacos_share_group:
        raise Exception("nacos配置错误")
    try:
        nacos_share_client = NacosClient(server_addresses=nacos_share_host, namespace=nacos_share_namespace, username=nacos_share_username, password=nacos_share_password)
        nacos_share_client.add_naming_instance(nacos_share_data_id, HostHelper.get_host_ip(), int(config.get_value("run_port")), heartbeat_interval=5, group_name=nacos_share_group)
        # 从Nacos获取配置，并更新到Flask应用的config对象中，以便在应用中使用这些配置
        config_content = nacos_share_client.get_config(data_id=nacos_share_data_id, group=nacos_share_group)
        share_config.init_config_from_nacos(config_file, config_content)
    except Exception as ex:
        logger_error.error(f"nacos连接失败:{ex},将使用本地配置。")
        share_config.init_config(config_file)
    # 添加配置监听器，当Nacos中的配置发生变化时，自动更新Flask应用的config对象
    try:
        nacos_share_client.add_config_watcher(data_id=nacos_share_data_id, group=nacos_share_group, cb=lambda cfg: share_config.init_config_from_nacos(config_file, cfg["content"]))
    except:
        pass



# -*- coding: utf-8 -*-
"""
:Author: HuangJianYi
:Date: 2021-07-15 11:54:54
@LastEditTime: 2025-02-21 15:22:25
@LastEditors: HuangJianYi
:description: 时间帮助类
"""
from seven_framework import *
import datetime



class TimeExHelper:
    """
    :description: 时间帮助类
    """

    @classmethod
    def get_now_int(self, hours=0, minutes=0, fmt='%Y%m%d%H%M%S'):
        """
        :description: 获取整形的时间 格式为yyyyMMddHHmmss，如2009年12月27日9点10分10秒表示为20091227091010
        :param hours: 需要增加的小时数
        :param hours: 需要增加的分钟数
        :param fmt: 时间格式
        :return:
        :last_editors: HuangJianYi
        """
        now_date = (datetime.datetime.now() + datetime.timedelta(minutes=minutes, hours=hours))
        return int(now_date.strftime(fmt))

    @classmethod
    def get_now_hour_int(self, hours=0):
        """
        :description: 获取整形的小时2020050612
        :param hours: 需要增加的小时数
        :return: int（2020050612）
        :last_editors: HuangJianYi
        """
        return self.get_now_int(hours=hours, fmt='%Y%m%d%H')

    @classmethod
    def get_now_day_int(self, hours=0):
        """
        :description: 获取整形的天20200506
        :param hours: 需要增加的小时数
        :return: int（20200506）
        :last_editors: HuangJianYi
        """
        return self.get_now_int(hours=hours, fmt='%Y%m%d')

    @classmethod
    def get_now_month_int(self, hours=0):
        """
        :description: 获取整形的月202005
        :param hours: 需要增加的小时数
        :return: int（202005）
        :last_editors: HuangJianYi
        """
        return self.get_now_int(hours=hours,fmt='%Y%m')

    @classmethod
    def get_date_list(self, start_date, end_date):
        """
        :description: 两个日期之间的日期列表
        :param start_date：开始日期
        :param end_date：结束日期
        :return: list
        :last_editors: HuangJianYi
        """
        if not start_date or not end_date:
            return []
        if ":" not in start_date:
            start_date+=" 00:00:00"
        if ":" not in end_date:
            end_date += " 00:00:00"
        datestart = datetime.datetime.strptime(start_date, '%Y-%m-%d %H:%M:%S')
        dateend = datetime.datetime.strptime(end_date, '%Y-%m-%d %H:%M:%S')

        date_list = []

        while datestart < dateend:
            date_list.append(datestart.strftime('%Y-%m-%d'))
            datestart += datetime.timedelta(days=1)
        return date_list
    
    @classmethod
    def get_week_day_list(self, fmt='%Y%m%d'):
        """
        :description: 获取本周日期列表
        :param fmt: 时间格式
        :return list
        :last_editors: HuangJianYi
        """
        week_day_list = []
        now_datetime = TimeHelper.get_now_datetime()
        for i in range(7):
            cur_day = int((now_datetime + datetime.timedelta(days=i - now_datetime.weekday())).date().strftime(fmt))
            week_day_list.append(cur_day)
        return week_day_list

    @classmethod
    def convert_custom_date(self, dt):
        """
        :description: 转换自定义文本时间
        :param dt: datetime格式时间或时间字符串
        :return: str
        :last_editors: HuangJianYi
        """
        now_timestamp = TimeHelper.get_now_timestamp()
        difference_seconds = TimeHelper.difference_seconds(now_timestamp, dt)
        if difference_seconds <= 1:
            return "刚刚"
        elif difference_seconds < 60:
            return  str(difference_seconds) + "秒前"
        elif difference_seconds >= 60 and difference_seconds < 3600:
            return str(int(difference_seconds / 60)) + "分钟前"
        elif difference_seconds >= 3600 and difference_seconds < 24 * 3600:
            return str(int(difference_seconds / 3600)) + "小时前"
        else:
            return str(int(difference_seconds / (24 * 3600))) + "天前"

    @classmethod
    def convert_bj_to_rfc(self, time_str=None):
        """
        :description: 北京时间转换成RFC 3339时间格式
        :param time_str: datetime格式时间
        :return: RFC 3339时间格式字符串
        :last_editors: HuangJianYi
        """
        import pytz
        if not time_str:
            time_str = TimeHelper.get_now_datetime()
        # 设置所需时区（例如：东八区）
        target_timezone = pytz.timezone('Asia/Shanghai')
        # 转换为目标时区的时间
        target_time = time_str.astimezone(target_timezone)
        # 格式化为指定的时间格式
        formatted_time = target_time.strftime('%Y-%m-%dT%H:%M:%S.%f%z')
        return formatted_time
    
    @classmethod
    def convert_bj_to_utc(self, time_str, fmt='%Y-%m-%d %H:%M:%S'):
        """
        :description: 北京时间转UTC时间
        :param time_str: 北京时间字符串
        :param fmt: 时间格式
        :return: utc时间，比北京时间少8小时
        :last_editors: HuangJianYi
        """
        import pytz
        # 将字符串转换为datetime对象，并设置为北京时区
        beijing_tz = pytz.timezone('Asia/Shanghai')
        bj_dt = datetime.strptime(time_str, fmt)
        bj_dt = beijing_tz.localize(bj_dt)
        # 转换为UTC时间
        utc_dt = bj_dt.astimezone(pytz.utc)
        return utc_dt.strftime(fmt)
    
    @classmethod
    def convert_utc_to_bj(self, time_str, fmt='%Y-%m-%d %H:%M:%S'):
        """
        :description: UTC时间转北京时间
        :param time_str: utc时间字符串
        :param fmt: 时间格式
        :return:  北京时间
        :last_editors: HuangJianYi
        """
        import pytz
        # 将字符串转换为datetime对象，并设置为UTC时区
        utc_tz = pytz.UTC
        utc_dt = datetime.strptime(time_str, fmt)
        utc_dt = utc_tz.localize(utc_dt)
        # 转换为北京时间
        beijing_tz = pytz.timezone('Asia/Shanghai')
        bj_dt = utc_dt.astimezone(beijing_tz)
        return bj_dt.strftime(fmt)

    @classmethod
    def get_format_date(self, dt):
        """
        :description: 将时间字符串格式化为日期 + "00:00:00" 的格式
        :param dt: utc时间字符串
        :return:  格式化后的字符串，格式为 "YYYY-MM-DD 00:00:00"。
        :last_editors: HuangJianYi
        """
        try:
            if isinstance(dt, str):
                # 将输入字符串解析为 datetime 对象
                dt = datetime.datetime.strptime(dt, "%Y-%m-%d %H:%M:%S")
            # 将时间部分设置为 00:00:00
            dt = dt.replace(hour=0, minute=0, second=0)
            # 格式化为字符串
            format_time = dt.strftime("%Y-%m-%d %H:%M:%S")
            return format_time
        except ValueError as e:
            # 如果输入格式不正确，抛出异常
            raise ValueError(f"输入的时间字符串格式不正确")
    
